
FIRST_PART = [
    'Champ, ',
    'Fact, ',
    'Everybody says ',
    'Dang... ',
    'Check it: ',
    'Just saying... ',
    'Superstar, ',
    'Tiger, ',
    'Self, ',
    'Know this, ',
    'News alert, ',
    'Ace, ',
    'Excuse me but ',
    'Experts agree ',
    'In my opinion ',
    'Hear ye, hear ye: ',
    'Okay, listen up: ',
]

SECOND_PART = [
    'the mere idea of you ',
    'your soul ',
    'your hair today ',
    'everything you do ',
    'your personal style ',
    'every thought you have ',
    'your presence here ',
    'what you got going on ',
    'the essential you ',
    'your life\'s journey ',
    'that saucy personality ',
    'your DNA ',
    'that brain of yours ',
    'your choice of attire ',
    'the way you roll ',
    'whatever your secret is ',
    'all of y\'all ',
]

THIRD_PART = [
    'has serious game, ',
    'rains magic, ',
    'deserves the Nobel Prize, ',
    'raises the roof, ',
    'breeds miracles, ',
    'is paying off big time, ',
    'shows mad skills ',
    'just shimmers ',
    'is a national treasure ',
    'gets the party hopping, ',
    'is the next big thing, ',
    'roars like a lion, ',
    'is a rainbow factory, ',
    'is made of diamonds, ',
    'makes birds sing, ',
    'should be taught in schools, ',
    'makes my world go \'round, ',
    'is 100% legit ',
]

FOURTH_PART = [
    '24/7.',
    'can I get an amen?',
    'and that\'s a fact.',
    'so treat yourself.',
    'you feel me?',
    'that\'s just science',
    'would I lie?',
    'for reals.',
    'mic drop.',
    'you hidden gem.',
    'snuggle bear.',
    'period.',
    'now let\'s dance.',
    'high five.',
    'say it again!',
    'according to BBC',
    'so get used to it.',
]

PARTS = [
    FIRST_PART,
    SECOND_PART,
    THIRD_PART,
    FOURTH_PART,
]



import argparse

from pep_talk.pep_parts import PARTS
from colored import stylize
import colored
import random


def print_pep():
    args = setup_args()

    message: str = ''
    mark_up: str = ''

    for values in PARTS:
        message += values[random.randint(0, len(values) - 1)]

    if args.fg:
        mark_up += colored.fg(args.fg)
    if args.bg:
        mark_up += colored.bg(args.bg)
    if args.attr:
        mark_up += colored.attr(args.attr)

    if mark_up:
        print(stylize(f'{message}', mark_up))
    else:
        print(message)


def setup_args() -> argparse.Namespace:
    parser = argparse.ArgumentParser(
        description='Output some pep! Colors are '
                    'defined here: https://pypi.org/project/colored/')

    parser.add_argument('--fg', help='foreground colour')
    parser.add_argument('--attr', help='text attributes colour, bold etd')
    parser.add_argument('--bg', help='background colour')
    return parser.parse_args()


if __name__ == '__main__':
    print_pep()



import setuptools

import pep_talk

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='pep_talk',
    version=pep_talk.__version__,
    author='Chris Hannam',
    author_email='ch@chrishannam.co.uk',
    description='Get a little bit of a boost today.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/chrishannam/pep-talk',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
    ],
    install_requires=['colored'],
    packages=['pep_talk'],
    entry_points={
        'console_scripts': [
            'pep-talk=pep_talk.main:print_pep',
        ]
    },
)